# Super Tab Nanny

_An inofficial rewrite of the standard library’s [tabnanny] module_

**Super Tab Nanny** is still in training.
She will frown upon ambiguous indentations in the same way as the original one,
and she will be just as merciless.


* * *
[tabnanny]: https://docs.python.org/3/library/tabnanny.html
